"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.name = void 0;
const Service_1 = __importDefault(require("@sudobot/core/Service"));
const FileSystem_1 = __importDefault(require("@sudobot/polyfills/FileSystem"));
const logger_1 = require("@sudobot/utils/logger");
const utils_1 = require("@sudobot/utils/utils");
const download_1 = require("@sudobot/utils/download");
exports.name = "urlfish";
class URLFishService extends Service_1.default {
    constructor() {
        super(...arguments);
        this.domainListURL = "https://raw.githubusercontent.com/mitchellkrogza/Phishing.Database/master/phishing-domains-ACTIVE.txt";
        this._list = [];
    }
    async boot() {
        const urlfishDir = (0, utils_1.sudoPrefix)("tmp/urlfish", true);
        const dataFile = (0, utils_1.sudoPrefix)("tmp/urlfish/LIST", false);
        if (await FileSystem_1.default.exists(dataFile)) {
            (0, logger_1.logDebug)("URLFishService", "Phishing domain list already exists", dataFile);
        }
        else {
            (0, logger_1.logDebug)("URLFishService", "Phishing domain list not found", dataFile);
            (0, logger_1.logDebug)("URLFishService", "Downloading list", dataFile);
            const url = this.domainListURL;
            await (0, download_1.downloadFile)({
                url,
                name: "LIST",
                path: urlfishDir
            });
        }
        const data = (await FileSystem_1.default.readFileContents(dataFile)).split("\n");
        (0, logger_1.logDebug)("URLFishService", `Loaded ${data.length} entries from file`);
        this._list = data;
    }
    get list() {
        return this._list;
    }
    scanMessage(message) {
        const urls = message.content.toLowerCase().split(" ");
        const phishingURLs = [];
        for (const url of urls) {
            const domain = url.startsWith("http") ? url.replace(/https?:\/?\/?/i, '') : url;
            if (this.list.includes(domain)) {
                phishingURLs.push(url);
            }
        }
        return phishingURLs;
    }
}
exports.default = URLFishService;
